CREATE USER PAYMENTS
  IDENTIFIED BY "change_on_install"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

CREATE TABLE PAYMENTS.PAYMENTS (
  "ID" NUMBER,
  "Date" DATE DEFAULT NULL,
  "Sum" BINARY_DOUBLE DEFAULT NULL,
  "AccountName" NVARCHAR2(50) DEFAULT NULL,
  "CompanyName" NVARCHAR2(50) DEFAULT NULL,
  "ItemName" NVARCHAR2(50) DEFAULT NULL,
  "Comment" NVARCHAR2(255) DEFAULT NULL,
  CONSTRAINT PK_PAYMENTS
    PRIMARY KEY ("ID")
);

CREATE SEQUENCE PAYMENTS.SQ_PAYMENTS_ID
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER PAYMENTS.TBIUR_PAYMENTS_ID
 BEFORE INSERT OR UPDATE
 ON PAYMENTS.PAYMENTS
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT SQ_PAYMENTS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE INDEX PAYMENTS.IX_PAYMENTS_DATE
    ON PAYMENTS.PAYMENTS
    (
        "Date"
    );

GRANT SELECT ON SAVETODB_XLS.VIEW_COLUMN_TRANSLATION TO PAYMENTS WITH GRANT OPTION;

CREATE OR REPLACE PROCEDURE PAYMENTS.CASH_FLOW (
    Year IN NUMBER
    , DataLanguage IN VARCHAR2
    , DATA OUT SYS_REFCURSOR
    )
IS
BEGIN

OPEN DATA FOR
SELECT
    p.RowNumber AS N
    , MAX(p."Level") AS "Level"
    , p."ItemType" AS "ItemType"
    , p."ItemName" AS "ItemName"
    , p."CompanyName"
    , MAX(COALESCE(t.TRANSLATED_NAME, p.Name)) AS "Name"
    , SUM(p.Total) AS "Total"
    , SUM(p."Jan") AS "Jan"
    , SUM(p."Feb") AS "Feb"
    , SUM(p."Mar") AS "Mar"
    , SUM(p."Apr") AS "Apr"
    , SUM(p."May") AS "May"
    , SUM(p."Jun") AS "Jun"
    , SUM(p."Jul") AS "Jul"
    , SUM(p."Aug") AS "Aug"
    , SUM(p."Sep") AS "Sep"
    , SUM(p."Oct") AS "Oct"
    , SUM(p."Nov") AS "Nov"
    , SUM(p."Dec") AS "Dec"
FROM
    (
    -- Companies
    SELECT
        p.RowNumber
        , 0 AS "Level"
        , p."ItemType"
        , p."ItemName"
        , p."CompanyName"
        , CONCAT('  ', p."CompanyName") AS Name
        , p.Period
        , p."Sum" AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            CAST(CASE WHEN p."Sum"<0 THEN 5 ELSE 3 END AS INTEGER) AS RowNumber
            , CAST(CASE WHEN p."Sum"<0 THEN 'Expenses' ELSE 'Income' END AS NVARCHAR2(255)) AS "ItemType"
            , p."ItemName"
            , p."CompanyName"
            , EXTRACT(MONTH FROM p."Date") AS Period
            , p."Sum"
        FROM
            PAYMENTS.PAYMENTS p
        WHERE
            p."CompanyName" IS NOT NULL
            AND EXTRACT(YEAR FROM p."Date") = Year
        ) p

    -- Total Items
    UNION ALL
    SELECT
        p.RowNumber
        , 1 AS "Level"
        , p."ItemType"
        , p."ItemName"
        , NULL AS "CompanyName"
        , p."ItemName" AS Name
        , p.Period
        , p."Sum" AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            CAST(CASE WHEN p."Sum"<0 THEN 5 ELSE 3 END AS INTEGER) AS RowNumber
            , CAST(CASE WHEN p."Sum"<0 THEN 'Expenses' ELSE 'Income' END AS NVARCHAR2(255)) AS "ItemType"
            , p."ItemName"
            , EXTRACT(MONTH FROM p."Date") AS Period
            , p."Sum"
        FROM
            PAYMENTS.PAYMENTS p
        WHERE
            p."ItemName" IS NOT NULL
            AND EXTRACT(YEAR FROM p."Date") = Year
        ) p

    -- Total Income/Expenses
    UNION ALL
    SELECT
        p.RowNumber
        , 2 AS "Level"
        , p."ItemType"
        , NULL AS "ItemName"
        , NULL AS "CompanyName"
        , CONCAT('Total ', p."ItemType") AS Name
        , p.Period
        , p."Sum" AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            CAST(CASE WHEN p."Sum"<0 THEN 4 ELSE 2 END AS INTEGER) AS RowNumber
            , CAST(CASE WHEN p."Sum"<0 THEN 'Expenses' ELSE 'Income' END AS NVARCHAR2(255)) AS "ItemType"
            , EXTRACT(MONTH FROM p."Date") AS Period
            , p."Sum"
        FROM
            PAYMENTS.PAYMENTS p
        WHERE
            EXTRACT(YEAR FROM p."Date") = Year
        ) p

    -- Net Chanhge
    UNION ALL
    SELECT
        6 AS RowNumber
        , 2 AS "Level"
        , N'Net Change' AS "ItemType"
        , NULL AS "ItemName"
        , NULL AS "CompanyName"
        , N'Net Change' AS Name
        , p.Period
        , p."Sum" AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            EXTRACT(MONTH FROM p."Date") AS Period
            , p."Sum"
        FROM
            PAYMENTS.PAYMENTS p
        WHERE
            EXTRACT(YEAR FROM p."Date") = Year
        ) p

    -- Opening balance
    UNION ALL
    SELECT
        1 AS RowNumber
        , 3 AS "Level"
        , N'Opening Balance' AS "ItemType"
        , NULL AS "ItemName"
        , NULL AS "CompanyName"
        , N'Opening Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            p.M AS Period
            , p."Sum"
        FROM
            (
            SELECT
                d.M
                , p."Date" AS "Date1"
                , p."Sum" AS "Sum"
            FROM
                (
                    SELECT 1 AS M FROM DUAL
                    UNION ALL SELECT 2 FROM DUAL
                    UNION ALL SELECT 3 FROM DUAL
                    UNION ALL SELECT 4 FROM DUAL
                    UNION ALL SELECT 5 FROM DUAL
                    UNION ALL SELECT 6 FROM DUAL
                    UNION ALL SELECT 7 FROM DUAL
                    UNION ALL SELECT 8 FROM DUAL
                    UNION ALL SELECT 9 FROM DUAL
                    UNION ALL SELECT 10 FROM DUAL
                    UNION ALL SELECT 11 FROM DUAL
                    UNION ALL SELECT 12 FROM DUAL
                ) d
                , PAYMENTS.PAYMENTS p
            ) p
        WHERE
            EXTRACT(YEAR FROM p."Date1") < Year
            OR (EXTRACT(YEAR FROM p."Date1") = Year AND EXTRACT(MONTH FROM p."Date1") < p.M)
        ) p

    -- Closing balance
    UNION ALL
    SELECT
        7 AS RowNumber
        , 3 AS "Level"
        , N'Closing Balance' AS "ItemType"
        , NULL AS "ItemName"
        , NULL AS "CompanyName"
        , N'Closing Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            p.M AS Period
            , p."Sum"
        FROM
            (
            SELECT
                d.M
                , p."Date" AS "Date1"
                , p."Sum" AS "Sum"
            FROM
                (
                    SELECT 1 AS M FROM DUAL
                    UNION ALL SELECT 2 FROM DUAL
                    UNION ALL SELECT 3 FROM DUAL
                    UNION ALL SELECT 4 FROM DUAL
                    UNION ALL SELECT 5 FROM DUAL
                    UNION ALL SELECT 6 FROM DUAL
                    UNION ALL SELECT 7 FROM DUAL
                    UNION ALL SELECT 8 FROM DUAL
                    UNION ALL SELECT 9 FROM DUAL
                    UNION ALL SELECT 10 FROM DUAL
                    UNION ALL SELECT 11 FROM DUAL
                    UNION ALL SELECT 12 FROM DUAL
                ) d
                , PAYMENTS.PAYMENTS p
            ) p
        WHERE
            EXTRACT(YEAR FROM p."Date1") < Year
            OR (EXTRACT(YEAR FROM p."Date1") = Year AND EXTRACT(MONTH FROM p."Date1") <= p.M)
        ) p
    ) p
    LEFT OUTER JOIN SAVETODB_XLS.VIEW_COLUMN_TRANSLATION t ON t.TABLE_SCHEMA = 'PAYMENTS' AND t.TABLE_NAME = 'ItemName' AND t.COLUMN_NAME = p.Name
        AND UPPER(t.LANGUAGE_NAME) = UPPER(DataLanguage)
GROUP BY
    p.RowNumber
    , p."ItemType"
    , p."ItemName"
    , p."CompanyName"
ORDER BY
    p.RowNumber
    , p."ItemType"
    , p."ItemName"
    , p."CompanyName";

END;
/


CREATE OR REPLACE PROCEDURE PAYMENTS.CASH_FLOW_SUMMARY (
    Year IN NUMBER
    , DataLanguage IN VARCHAR2
    , DATA OUT SYS_REFCURSOR
    )
IS
BEGIN

OPEN DATA FOR
SELECT
    p.RowNumber AS N
    , MAX(p."Level") AS "Level"
    , p."ItemType" AS "ItemType"
    , p."ItemName" AS "ItemName"
    , p."CompanyName"
    , MAX(COALESCE(t.TRANSLATED_NAME, p.Name)) AS "Name"
    , SUM(p.Total) AS "Total"
    , SUM(p."Jan") AS "Jan"
    , SUM(p."Feb") AS "Feb"
    , SUM(p."Mar") AS "Mar"
    , SUM(p."Apr") AS "Apr"
    , SUM(p."May") AS "May"
    , SUM(p."Jun") AS "Jun"
    , SUM(p."Jul") AS "Jul"
    , SUM(p."Aug") AS "Aug"
    , SUM(p."Sep") AS "Sep"
    , SUM(p."Oct") AS "Oct"
    , SUM(p."Nov") AS "Nov"
    , SUM(p."Dec") AS "Dec"
FROM
    (
    -- Total Items
    SELECT
        p.RowNumber
        , 1 AS "Level"
        , p."ItemType"
        , p."ItemName"
        , NULL AS "CompanyName"
        , p."ItemName" AS Name
        , p.Period
        , p."Sum" AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            CAST(CASE WHEN p."Sum"<0 THEN 5 ELSE 3 END AS INTEGER) AS RowNumber
            , CAST(CASE WHEN p."Sum"<0 THEN 'Expenses' ELSE 'Income' END AS NVARCHAR2(255)) AS "ItemType"
            , p."ItemName"
            , EXTRACT(MONTH FROM p."Date") AS Period
            , p."Sum"
        FROM
            PAYMENTS.PAYMENTS p
        WHERE
            p."ItemName" IS NOT NULL
            AND EXTRACT(YEAR FROM p."Date") = Year
        ) p

    -- Total Income/Expenses
    UNION ALL
    SELECT
        p.RowNumber
        , 2 AS "Level"
        , p."ItemType"
        , NULL AS "ItemName"
        , NULL AS "CompanyName"
        , CONCAT('Total ', p."ItemType") AS Name
        , p.Period
        , p."Sum" AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            CAST(CASE WHEN p."Sum"<0 THEN 4 ELSE 2 END AS INTEGER) AS RowNumber
            , CAST(CASE WHEN p."Sum"<0 THEN 'Expenses' ELSE 'Income' END AS NVARCHAR2(255)) AS "ItemType"
            , EXTRACT(MONTH FROM p."Date") AS Period
            , p."Sum"
        FROM
            PAYMENTS.PAYMENTS p
        WHERE
            EXTRACT(YEAR FROM p."Date") = Year
        ) p

    -- Net Chanhge
    UNION ALL
    SELECT
        6 AS RowNumber
        , 2 AS "Level"
        , N'Net Change' AS "ItemType"
        , NULL AS "ItemName"
        , NULL AS "CompanyName"
        , N'Net Change' AS Name
        , p.Period
        , p."Sum" AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            EXTRACT(MONTH FROM p."Date") AS Period
            , p."Sum"
        FROM
            PAYMENTS.PAYMENTS p
        WHERE
            EXTRACT(YEAR FROM p."Date") = Year
        ) p

    -- Opening balance
    UNION ALL
    SELECT
        1 AS RowNumber
        , 3 AS "Level"
        , N'Opening Balance' AS "ItemType"
        , NULL AS "ItemName"
        , NULL AS "CompanyName"
        , N'Opening Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            p.M AS Period
            , p."Sum"
        FROM
            (
            SELECT
                d.M
                , p."Date" AS "Date1"
                , p."Sum" AS "Sum"
            FROM
                (
                    SELECT 1 AS M FROM DUAL
                    UNION ALL SELECT 2 FROM DUAL
                    UNION ALL SELECT 3 FROM DUAL
                    UNION ALL SELECT 4 FROM DUAL
                    UNION ALL SELECT 5 FROM DUAL
                    UNION ALL SELECT 6 FROM DUAL
                    UNION ALL SELECT 7 FROM DUAL
                    UNION ALL SELECT 8 FROM DUAL
                    UNION ALL SELECT 9 FROM DUAL
                    UNION ALL SELECT 10 FROM DUAL
                    UNION ALL SELECT 11 FROM DUAL
                    UNION ALL SELECT 12 FROM DUAL
                ) d
                , PAYMENTS.PAYMENTS p
            ) p
        WHERE
            EXTRACT(YEAR FROM p."Date1") < Year
            OR (EXTRACT(YEAR FROM p."Date1") = Year AND EXTRACT(MONTH FROM p."Date1") < p.M)
        ) p

    -- Closing balance
    UNION ALL
    SELECT
        7 AS RowNumber
        , 3 AS "Level"
        , N'Closing Balance' AS "ItemType"
        , NULL AS "ItemName"
        , NULL AS "CompanyName"
        , N'Closing Balance' AS Name
        , p.Period
        , NULL AS Total
        , CASE p.Period WHEN  1 THEN p."Sum" ELSE 0 END AS "Jan"
        , CASE p.Period WHEN  2 THEN p."Sum" ELSE 0 END AS "Feb"
        , CASE p.Period WHEN  3 THEN p."Sum" ELSE 0 END AS "Mar"
        , CASE p.Period WHEN  4 THEN p."Sum" ELSE 0 END AS "Apr"
        , CASE p.Period WHEN  5 THEN p."Sum" ELSE 0 END AS "May"
        , CASE p.Period WHEN  6 THEN p."Sum" ELSE 0 END AS "Jun"
        , CASE p.Period WHEN  7 THEN p."Sum" ELSE 0 END AS "Jul"
        , CASE p.Period WHEN  8 THEN p."Sum" ELSE 0 END AS "Aug"
        , CASE p.Period WHEN  9 THEN p."Sum" ELSE 0 END AS "Sep"
        , CASE p.Period WHEN 10 THEN p."Sum" ELSE 0 END AS "Oct"
        , CASE p.Period WHEN 11 THEN p."Sum" ELSE 0 END AS "Nov"
        , CASE p.Period WHEN 12 THEN p."Sum" ELSE 0 END AS "Dec"
    FROM
        (
        SELECT
            p.M AS Period
            , p."Sum"
        FROM
            (
            SELECT
                d.M
                , p."Date" AS "Date1"
                , p."Sum" AS "Sum"
            FROM
                (
                    SELECT 1 AS M FROM DUAL
                    UNION ALL SELECT 2 FROM DUAL
                    UNION ALL SELECT 3 FROM DUAL
                    UNION ALL SELECT 4 FROM DUAL
                    UNION ALL SELECT 5 FROM DUAL
                    UNION ALL SELECT 6 FROM DUAL
                    UNION ALL SELECT 7 FROM DUAL
                    UNION ALL SELECT 8 FROM DUAL
                    UNION ALL SELECT 9 FROM DUAL
                    UNION ALL SELECT 10 FROM DUAL
                    UNION ALL SELECT 11 FROM DUAL
                    UNION ALL SELECT 12 FROM DUAL
                ) d
                , PAYMENTS.PAYMENTS p
            ) p
        WHERE
            EXTRACT(YEAR FROM p."Date1") < Year
            OR (EXTRACT(YEAR FROM p."Date1") = Year AND EXTRACT(MONTH FROM p."Date1") <= p.M)
        ) p
    ) p
    LEFT OUTER JOIN SAVETODB_XLS.VIEW_COLUMN_TRANSLATION t ON t.TABLE_SCHEMA = 'PAYMENTS' AND t.TABLE_NAME = 'ItemName' AND t.COLUMN_NAME = p.Name
        AND UPPER(t.LANGUAGE_NAME) = UPPER(DataLanguage)
GROUP BY
    p.RowNumber
    , p."ItemType"
    , p."ItemName"
    , p."CompanyName"
ORDER BY
    p.RowNumber
    , p."ItemType"
    , p."ItemName"
    , p."CompanyName";

END;
/

ALTER SESSION SET NLS_DATE_FORMAT='YYYY-MM-DD HH24:MI:SS';
ALTER SESSION SET NLS_TIMESTAMP_FORMAT='YYYY-MM-DD HH24:MI:SSXFF';
ALTER SESSION SET NLS_TIMESTAMP_TZ_FORMAT='YYYY-MM-DD HH24:MI:SSXFF TZH:TZM';

INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2014-12-31',10000,'My Bank',NULL,NULL,'Opening balance');
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-01-10',200000,'My Bank','Rose, Inc','Revenue',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-01-10',-50000,'My Bank','Land, Inc','Expenses',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-01-31',-13000,'My Bank','Income Taxes','Taxes',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-01-31',-29580,'My Bank','Salary Taxes','Taxes',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-01-31',-87000,'My Bank',NULL,'Payroll',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-02-10',300000,'My Bank','Rose, Inc','Revenue',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-02-10',100000,'My Bank','Carnation, Inc','Revenue',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-02-10',-50000,'My Bank','Water, Inc','Expenses',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-02-10',-100000,'My Bank','Land, Inc','Expenses',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-02-28',-13000,'My Bank','Income Taxes','Taxes',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-02-28',-29580,'My Bank','Salary Taxes','Taxes',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-02-28',-87000,'My Bank',NULL,'Payroll',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-10',300000,'My Bank','Rose, Inc','Revenue',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-10',200000,'My Bank','Carnation, Inc','Revenue',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-10',100000,'My Bank','Cornflower, Corp','Revenue',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-15',-36000,'My Bank','Corporate Tax','Taxes',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-31',-26000,'My Bank','Income Taxes','Taxes',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-31',-50000,'My Bank','Water, Inc','Expenses',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-31',-59160,'My Bank','Salary Taxes','Taxes',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-31',-100000,'My Bank','Land, Inc','Expenses',NULL);
INSERT INTO PAYMENTS.PAYMENTS ("Date","Sum","AccountName","CompanyName","ItemName","Comment") VALUES ('2015-03-31',-174000,'My Bank',NULL,'Payroll',NULL);


INSERT INTO SAVETODB_DEV.EVENT_HANDLERS ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","EVENT_NAME","HANDLER_CODE","HANDLER_SCHEMA","HANDLER_NAME","HANDLER_TYPE","TARGET_WORKSHEET","MENU_ORDER","EDIT_PARAMETERS") VALUES ('PAYMENTS','CASH_FLOW_SUMMARY',NULL,'ContextMenu','SELECT * FROM payments.payments p WHERE p."ItemName" = :ItemName','CODE','Payments - {ItemName}','CODE',NULL,11,NULL);
INSERT INTO SAVETODB_DEV.EVENT_HANDLERS ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","EVENT_NAME","HANDLER_CODE","HANDLER_SCHEMA","HANDLER_NAME","HANDLER_TYPE","TARGET_WORKSHEET","MENU_ORDER","EDIT_PARAMETERS") VALUES ('PAYMENTS','CASH_FLOW',NULL,'ContextMenu','SELECT * FROM payments.payments p WHERE p."CompanyName" = :CompanyName','CODE','Payments - {CompanyName}','CODE',NULL,12,NULL);
INSERT INTO SAVETODB_DEV.EVENT_HANDLERS ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","EVENT_NAME","HANDLER_CODE","HANDLER_SCHEMA","HANDLER_NAME","HANDLER_TYPE","TARGET_WORKSHEET","MENU_ORDER","EDIT_PARAMETERS") VALUES ('PAYMENTS','CASH_FLOW',NULL,'ContextMenu','SELECT * FROM payments.payments p WHERE p."ItemName" = :ItemName','CODE','Payments - {ItemName}','CODE',NULL,11,NULL);
INSERT INTO SAVETODB_DEV.EVENT_HANDLERS ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","EVENT_NAME","HANDLER_CODE","HANDLER_SCHEMA","HANDLER_NAME","HANDLER_TYPE","TARGET_WORKSHEET","MENU_ORDER","EDIT_PARAMETERS") VALUES ('PAYMENTS','PAYMENTS',NULL,'ContextMenu','SELECT * FROM payments.payments p WHERE p."CompanyName" = :CompanyName','CODE','Payments - {CompanyName}','CODE',NULL,12,NULL);
INSERT INTO SAVETODB_DEV.EVENT_HANDLERS ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","EVENT_NAME","HANDLER_CODE","HANDLER_SCHEMA","HANDLER_NAME","HANDLER_TYPE","TARGET_WORKSHEET","MENU_ORDER","EDIT_PARAMETERS") VALUES ('PAYMENTS','PAYMENTS',NULL,'ContextMenu','SELECT * FROM payments.payments p WHERE p."ItemName" = :ItemName','CODE','Payments - {ItemName}','CODE',NULL,11,NULL);
INSERT INTO SAVETODB_DEV.EVENT_HANDLERS ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","EVENT_NAME","HANDLER_CODE","HANDLER_SCHEMA","HANDLER_NAME","HANDLER_TYPE","TARGET_WORKSHEET","MENU_ORDER","EDIT_PARAMETERS") VALUES ('PAYMENTS','PAYMENTS',NULL,'ContextMenu','SELECT * FROM payments.payments p WHERE p."Date" = TO_DATE(:Date, ''YYYY-MM-DD  HH24:MI:SS'')','CODE','Payments - {Date}','CODE',NULL,13,NULL);

INSERT INTO SAVETODB_DEV.PARAMETER_VALUES ("TABLE_SCHEMA","TABLE_NAME","PARAMETER_NAME","SELECT_CODE","SELECT_SCHEMA","SELECT_NAME","SELECT_TYPE") VALUES ('PAYMENTS','CASH_FLOW','Year','SELECT DISTINCT EXTRACT(YEAR FROM "Date") AS "Year" FROM payments.payments WHERE "Date" > ''20111231'' ORDER BY EXTRACT(YEAR FROM "Date") DESC','CODE','PaymentsYear','CODE');
INSERT INTO SAVETODB_DEV.PARAMETER_VALUES ("TABLE_SCHEMA","TABLE_NAME","PARAMETER_NAME","SELECT_CODE","SELECT_SCHEMA","SELECT_NAME","SELECT_TYPE") VALUES ('PAYMENTS','CASH_FLOW_SUMMARY','Year','SELECT DISTINCT EXTRACT(YEAR FROM "Date") AS "Year" FROM payments.payments WHERE "Date" > ''20111231'' ORDER BY EXTRACT(YEAR FROM "Date") DESC','CODE','PaymentsYear','CODE');

INSERT INTO SAVETODB_DEV.OBJECT_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC","TRANSLATED_COMMENT") VALUES ('CODE','Payments - {CompanyName}','en',NULL,NULL,NULL);
INSERT INTO SAVETODB_DEV.OBJECT_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC","TRANSLATED_COMMENT") VALUES ('CODE','Payments - {ItemName}','en',NULL,NULL,NULL);
INSERT INTO SAVETODB_DEV.OBJECT_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC","TRANSLATED_COMMENT") VALUES ('CODE','Payments - {Date}','en',NULL,NULL,NULL);

INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Opening Balance','en','Opening Balance',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Total Income','en','Total Income',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Revenue','en','Revenue',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Total Expenses','en','Total Expenses',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Expenses','en','Expenses',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Payroll','en','Payroll',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Taxes','en','Taxes',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Net Change','en','Net Change',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','ItemName','Closing Balance','en','Closing Balance',NULL);
INSERT INTO SAVETODB_DEV.COLUMN_TRANSLATION ("TABLE_SCHEMA","TABLE_NAME","COLUMN_NAME","LANGUAGE_NAME","TRANSLATED_NAME","TRANSLATED_DESC") VALUES ('PAYMENTS','PAYMENTS','Sum','en','Amount',NULL);

DECLARE format varchar2(32767) := '<?xml version="1.0" encoding="Unicode"?>
<table name="PAYMENTS.PAYMENTS">
<columnFormats>
<column name="" property="ListObjectName" value="Sheet1_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium2" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="True" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$4" type="String" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$4" type="String" />
<column name="ID" property="ColumnWidth" value="0.08" type="Double" />
<column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Date" property="Address" value="$D$4" type="String" />
<column name="Date" property="ColumnWidth" value="10" type="Double" />
<column name="Date" property="NumberFormat" value="m/d/yyyy" type="String" />
<column name="Sum" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sum" property="Address" value="$E$4" type="String" />
<column name="Sum" property="ColumnWidth" value="11.71" type="Double" />
<column name="Sum" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="AccountName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="AccountName" property="Address" value="$F$4" type="String" />
<column name="AccountName" property="ColumnWidth" value="15.57" type="Double" />
<column name="CompanyName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$4" type="String" />
<column name="CompanyName" property="ColumnWidth" value="16.71" type="Double" />
<column name="ItemName" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ItemName" property="Address" value="$H$4" type="String" />
<column name="ItemName" property="ColumnWidth" value="17.71" type="Double" />
<column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Comment" property="Address" value="$I$4" type="String" />
<column name="Comment" property="ColumnWidth" value="21.71" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="Date" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="ID" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
</columnFormats>
</table>';

BEGIN
INSERT INTO SAVETODB_DEV.TABLE_FORMATS ("TABLE_SCHEMA","TABLE_NAME","TABLE_EXCEL_FORMAT_XML") VALUES ('PAYMENTS','PAYMENTS', format);
END;
/

DECLARE format varchar2(32767) := '<?xml version="1.0" encoding="Unicode"?>
<table name="PAYMENTS.CASH_FLOW">
<columnFormats>
<column name="" property="ListObjectName" value="CashFlow_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$5" type="String" />
<column name="N" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="N" property="Address" value="$C$5" type="String" />
<column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Level" property="Address" value="$D$5" type="String" />
<column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemType" property="Address" value="$E$5" type="String" />
<column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemName" property="Address" value="$F$5" type="String" />
<column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$5" type="String" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$H$5" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Total" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Total" property="Address" value="$I$5" type="String" />
<column name="Total" property="ColumnWidth" value="13.14" type="Double" />
<column name="Total" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jan" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jan" property="Address" value="$J$5" type="String" />
<column name="Jan" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jan" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Feb" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Feb" property="Address" value="$K$5" type="String" />
<column name="Feb" property="ColumnWidth" value="10.71" type="Double" />
<column name="Feb" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Mar" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mar" property="Address" value="$L$5" type="String" />
<column name="Mar" property="ColumnWidth" value="10.71" type="Double" />
<column name="Mar" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Apr" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Apr" property="Address" value="$M$5" type="String" />
<column name="Apr" property="ColumnWidth" value="10.71" type="Double" />
<column name="Apr" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="May" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="May" property="Address" value="$N$5" type="String" />
<column name="May" property="ColumnWidth" value="10.71" type="Double" />
<column name="May" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jun" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jun" property="Address" value="$O$5" type="String" />
<column name="Jun" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jun" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jul" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jul" property="Address" value="$P$5" type="String" />
<column name="Jul" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jul" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Aug" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Aug" property="Address" value="$Q$5" type="String" />
<column name="Aug" property="ColumnWidth" value="10.71" type="Double" />
<column name="Aug" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Sep" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sep" property="Address" value="$R$5" type="String" />
<column name="Sep" property="ColumnWidth" value="10.71" type="Double" />
<column name="Sep" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Oct" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Oct" property="Address" value="$S$5" type="String" />
<column name="Oct" property="ColumnWidth" value="10.71" type="Double" />
<column name="Oct" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Nov" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Nov" property="Address" value="$T$5" type="String" />
<column name="Nov" property="ColumnWidth" value="10.71" type="Double" />
<column name="Nov" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Dec" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Dec" property="Address" value="$U$5" type="String" />
<column name="Dec" property="ColumnWidth" value="10.71" type="Double" />
<column name="Dec" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D5=3" type="String" />
<column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Priority" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Formula1" value="=$D5=1" type="String" />
<column name="_RowNum" property="FormatConditions(2).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).Interior.Color" value="15853276" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.ThemeColor" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.TintAndShade" value="0.799981688894314" type="Double" />
<column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$5:$U$21" type="String" />
<column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Priority" value="6" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Formula1" value="=$D5=2" type="String" />
<column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6299648" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="7" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>';

BEGIN
INSERT INTO SAVETODB_DEV.TABLE_FORMATS ("TABLE_SCHEMA","TABLE_NAME","TABLE_EXCEL_FORMAT_XML") VALUES ('PAYMENTS','CASH_FLOW', format);
END;
/

DECLARE format varchar2(32767) := '<?xml version="1.0" encoding="Unicode"?>
<table name="PAYMENTS.CASH_FLOW_SUMMARY">
<columnFormats>
<column name="" property="ListObjectName" value="CashFlow_Table134" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$5" type="String" />
<column name="N" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="N" property="Address" value="$C$5" type="String" />
<column name="Level" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="Level" property="Address" value="$D$5" type="String" />
<column name="ItemType" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemType" property="Address" value="$E$5" type="String" />
<column name="ItemName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ItemName" property="Address" value="$F$5" type="String" />
<column name="CompanyName" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="CompanyName" property="Address" value="$G$5" type="String" />
<column name="Name" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Name" property="Address" value="$H$5" type="String" />
<column name="Name" property="ColumnWidth" value="27.86" type="Double" />
<column name="Total" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Total" property="Address" value="$I$5" type="String" />
<column name="Total" property="ColumnWidth" value="13.14" type="Double" />
<column name="Total" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jan" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jan" property="Address" value="$J$5" type="String" />
<column name="Jan" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jan" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Feb" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Feb" property="Address" value="$K$5" type="String" />
<column name="Feb" property="ColumnWidth" value="11" type="Double" />
<column name="Feb" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Mar" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Mar" property="Address" value="$L$5" type="String" />
<column name="Mar" property="ColumnWidth" value="10.71" type="Double" />
<column name="Mar" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Apr" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Apr" property="Address" value="$M$5" type="String" />
<column name="Apr" property="ColumnWidth" value="10.71" type="Double" />
<column name="Apr" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="May" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="May" property="Address" value="$N$5" type="String" />
<column name="May" property="ColumnWidth" value="10.71" type="Double" />
<column name="May" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jun" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jun" property="Address" value="$O$5" type="String" />
<column name="Jun" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jun" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Jul" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Jul" property="Address" value="$P$5" type="String" />
<column name="Jul" property="ColumnWidth" value="10.71" type="Double" />
<column name="Jul" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Aug" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Aug" property="Address" value="$Q$5" type="String" />
<column name="Aug" property="ColumnWidth" value="10.71" type="Double" />
<column name="Aug" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Sep" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Sep" property="Address" value="$R$5" type="String" />
<column name="Sep" property="ColumnWidth" value="10.71" type="Double" />
<column name="Sep" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Oct" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Oct" property="Address" value="$S$5" type="String" />
<column name="Oct" property="ColumnWidth" value="10.71" type="Double" />
<column name="Oct" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Nov" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Nov" property="Address" value="$T$5" type="String" />
<column name="Nov" property="ColumnWidth" value="10.71" type="Double" />
<column name="Nov" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="Dec" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="Dec" property="Address" value="$U$5" type="String" />
<column name="Dec" property="ColumnWidth" value="10.71" type="Double" />
<column name="Dec" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String" />
<column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D5=3" type="String" />
<column name="_RowNum" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="_RowNum" property="FormatConditions(2).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(2).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(2).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Priority" value="5" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Formula1" value="=$D5=1" type="String" />
<column name="_RowNum" property="FormatConditions(2).Interior.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.Pattern" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.PatternThemeColor" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(2).Interior.ThemeColor" value="-4142" type="Double" />
<column name="_RowNum" property="FormatConditions(3).AppliesToTable" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).AppliesTo.Address" value="$B$5:$U$13" type="String" />
<column name="_RowNum" property="FormatConditions(3).Type" value="2" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Priority" value="6" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Formula1" value="=$D5=2" type="String" />
<column name="_RowNum" property="FormatConditions(3).Font.Color" value="16777215" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.ThemeColor" value="1" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Font.Bold" value="True" type="Boolean" />
<column name="_RowNum" property="FormatConditions(3).Interior.Color" value="6299648" type="Double" />
<column name="_RowNum" property="FormatConditions(3).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="7" type="Double" />
<column name="" property="PageSetup.Orientation" value="2" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
<column name="" property="PageSetup.PaperSize" value="1" type="Double" />
<column name="" property="PageSetup.LeftMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.RightMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.TopMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.BottomMargin" value="25.511811023622" type="Double" />
<column name="" property="PageSetup.HeaderMargin" value="22.6771653543307" type="Double" />
<column name="" property="PageSetup.FooterMargin" value="22.6771653543307" type="Double" />
</columnFormats>
</table>';

BEGIN
INSERT INTO SAVETODB_DEV.TABLE_FORMATS ("TABLE_SCHEMA","TABLE_NAME","TABLE_EXCEL_FORMAT_XML") VALUES ('PAYMENTS','CASH_FLOW_SUMMARY', format);
END;
/

prompt Payments Application has been installed
