CREATE USER SAVETODB_DEV
  IDENTIFIED BY "change_on_install"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

CREATE USER SAVETODB_XLS
  IDENTIFIED BY "change_on_install"
    DEFAULT TABLESPACE USERS
    TEMPORARY TABLESPACE TEMP
    PROFILE "DEFAULT"
    ACCOUNT UNLOCK
    QUOTA UNLIMITED ON USERS;

prompt Users have been created

CREATE TABLE SAVETODB_DEV.QUERY_LIST
(
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30) NOT NULL,
  TABLE_NAME VARCHAR2(30) NOT NULL,
  TABLE_TYPE VARCHAR2(30) NOT NULL,
  TABLE_CODE NCLOB,
  INSERT_PROCEDURE NCLOB,
  UPDATE_PROCEDURE NCLOB,
  DELETE_PROCEDURE NCLOB,
  PROCEDURE_TYPE VARCHAR2(30),
  CONSTRAINT PK_QUERY_LIST
    PRIMARY KEY (ID)
);

CREATE SEQUENCE SAVETODB_DEV.SQ_QUERY_LIST_ID
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER SAVETODB_DEV.TBIUR_QUERY_LIST_ID
 BEFORE INSERT OR UPDATE
 ON SAVETODB_DEV.QUERY_LIST
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT sq_QUERY_LIST_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE OR REPLACE VIEW SAVETODB_DEV.VIEW_QUERY_LIST
(
    TABLE_SCHEMA,
    TABLE_NAME,
    TABLE_TYPE,
    TABLE_CODE,
    INSERT_PROCEDURE,
    UPDATE_PROCEDURE,
    DELETE_PROCEDURE,
    PROCEDURE_TYPE
)
AS
-- This code selects database objects
SELECT
    t.OWNER AS TABLE_SCHEMA
    , t.OBJECT_NAME AS TABLE_NAME
    , t.OBJECT_TYPE AS TABLE_TYPE
    , NULL AS TABLE_CODE
    
    -- Comment these lines if you select another way to get INSERT, UPDATE, and DELETE procedures
    , COALESCE(q.INSERT_PROCEDURE, TO_NCLOB(CASE WHEN i.OBJECT_NAME IS NULL THEN NULL ELSE i.OWNER || '.' || i.OBJECT_NAME END)) AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, TO_NCLOB(CASE WHEN u.OBJECT_NAME IS NULL THEN NULL ELSE u.OWNER || '.' || u.OBJECT_NAME END)) AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, TO_NCLOB(CASE WHEN d.OBJECT_NAME IS NULL THEN NULL ELSE d.OWNER || '.' || d.OBJECT_NAME END)) AS DELETE_PROCEDURE

    -- Use these lines if you use the sys.obj$ code
    --, COALESCE(q.INSERT_PROCEDURE, CASE WHEN i.NAME IS NULL THEN NULL ELSE t.OWNER || '.' || i.NAME END) AS INSERT_PROCEDURE
    --, COALESCE(q.UPDATE_PROCEDURE, CASE WHEN u.NAME IS NULL THEN NULL ELSE t.OWNER || '.' || u.NAME END) AS UPDATE_PROCEDURE
    --, COALESCE(q.DELETE_PROCEDURE, CASE WHEN d.NAME IS NULL THEN NULL ELSE t.OWNER || '.' || d.NAME END) AS DELETE_PROCEDURE

    -- Use these lines if SAVETODB_DEV.QUERY_LIST is used only
    --, q.INSERT_PROCEDURE
    --, q.UPDATE_PROCEDURE
    --, q.DELETE_PROCEDURE

    , COALESCE(q.PROCEDURE_TYPE, CASE WHEN i.OBJECT_NAME IS NOT NULL THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
FROM
    SYS.ALL_OBJECTS t
    -- SAVETODB_DEV.QUERY_LIST contains manual data for INSERT_PROCEDURE, UPDATE_PROCEDURE, and DELETE_PROCEDURE
    LEFT OUTER JOIN SAVETODB_DEV.QUERY_LIST q ON q.TABLE_SCHEMA = t.OWNER AND q.TABLE_NAME = t.OBJECT_NAME

    -- You may comment these lines to use SAVETODB_DEV.QUERY_LIST only or sys.obj$. The view will run much faster
    LEFT OUTER JOIN SYS.ALL_OBJECTS i ON i.OWNER = t.OWNER AND i.OBJECT_NAME = REPLACE(t.OBJECT_NAME, '_SELECT', '') || '_INSERT'
    LEFT OUTER JOIN SYS.ALL_OBJECTS u ON u.OWNER = t.OWNER AND u.OBJECT_NAME = REPLACE(t.OBJECT_NAME, '_SELECT', '') || '_UPDATE'
    LEFT OUTER JOIN SYS.ALL_OBJECTS d ON d.OWNER = t.OWNER AND d.OBJECT_NAME = REPLACE(t.OBJECT_NAME, '_SELECT', '') || '_DELETE'

    -- You may use these lines instead of SYS.ALL_OBJECTS. The view will run faster
    -- INNER JOIN sys.user$ s ON s.NAME = t.OWNER
    -- LEFT OUTER JOIN sys.obj$ i ON i.TYPE# = 7 AND i.owner# = s.user# AND i.NAME = REPLACE(t.OBJECT_NAME, '_SELECT', '') || '_INSERT'
    -- LEFT OUTER JOIN sys.obj$ u ON u.TYPE# = 7 AND u.owner# = s.user# AND u.NAME = REPLACE(t.OBJECT_NAME, '_SELECT', '') || '_UPDATE'
    -- LEFT OUTER JOIN sys.obj$ d ON d.TYPE# = 7 AND d.owner# = s.user# AND d.NAME = REPLACE(t.OBJECT_NAME, '_SELECT', '') || '_DELETE'
WHERE
    t.OWNER NOT IN (
        'APEX_030200', 'APPQOSSYS', 'CTXSYS', 'DBSNMP', 'EXFSYS', 'FLOWS_FILES', 'IX', 'MDSYS', 'OLAPSYS',
        'ORDDATA', 'ORDSYS', 'ORDPLUGINS', 'OUTLN', 'OWBSYS', 'SYS', 'SYSTEM', 'SYSMAN', 'WMSYS', 'XDB'
        )
    AND t.OBJECT_TYPE IN ('TABLE', 'VIEW', 'PROCEDURE')
    AND t.OBJECT_NAME NOT LIKE '%_INSERT'
    AND t.OBJECT_NAME NOT LIKE '%_UPDATE'
    AND t.OBJECT_NAME NOT LIKE '%_DELETE'
    AND t.OBJECT_NAME NOT LIKE '%_MERGE'
    AND t.OBJECT_NAME NOT LIKE 'XL_%'
UNION ALL
-- This code selects non-database objects specified in the SAVETODB_DEV.QUERY_LIST table
SELECT
    q.TABLE_SCHEMA
    , q.TABLE_NAME
    , q.TABLE_TYPE
    , q.TABLE_CODE
    , q.INSERT_PROCEDURE
    , q.UPDATE_PROCEDURE
    , q.DELETE_PROCEDURE
    , q.PROCEDURE_TYPE
FROM
    SAVETODB_DEV.QUERY_LIST q
    LEFT OUTER JOIN SYS.ALL_OBJECTS t ON q.TABLE_SCHEMA = t.OWNER AND q.TABLE_NAME = t.OBJECT_NAME
WHERE
    q.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND t.OBJECT_NAME IS NULL
ORDER BY
    TABLE_TYPE
    , TABLE_SCHEMA
    , TABLE_NAME;

GRANT SELECT ON SAVETODB_DEV.VIEW_QUERY_LIST TO SAVETODB_XLS WITH GRANT OPTION;

CREATE OR REPLACE VIEW SAVETODB_XLS.VIEW_QUERY_LIST (
    TABLE_SCHEMA,
    TABLE_NAME,
    TABLE_TYPE,
    TABLE_CODE,
    INSERT_PROCEDURE,
    UPDATE_PROCEDURE,
    DELETE_PROCEDURE,
    PROCEDURE_TYPE
    )
AS
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , t.TABLE_CODE
    , t.INSERT_PROCEDURE
    , t.UPDATE_PROCEDURE
    , t.DELETE_PROCEDURE
    , t.PROCEDURE_TYPE
FROM
    SAVETODB_DEV.VIEW_QUERY_LIST t
WHERE
    t.TABLE_SCHEMA NOT IN ('SAVETODB_DEV')
    AND t.TABLE_NAME NOT IN (
        'VIEW_QUERY_LIST'                       -- SaveToDB Framework 3.0
        , 'VIEW_EVENT_HANDLERS'
        , 'VIEW_TABLE_FORMATS'
        , 'VIEW_PARAMETER_VALUES'
        , 'VIEW_OBJECT_TRANSLATION'
        , 'VIEW_COLUMN_TRANSLATION'
        , 'TABLE_FORMAT_SAVE'
        , 'VIEW_EXCEL_EVENT_HANDLERS'           -- SaveToDB Framework 2.0
        , 'VIEW_EXCEL_TABLE_FORMATS'
        , 'VIEW_PARAMETER_VALUES_QUERIES'
        , 'VIEW_TRANSLATION_OBJECTS'
        , 'VIEW_TRANSLATION_COLUMNS'
        , 'EXCEL_TABLE_FORMAT_UPDATE'
    );

prompt QueryList objects have been created

CREATE TABLE SAVETODB_DEV.OBJECT_TRANSLATION
(
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30) NOT NULL,
  TABLE_NAME VARCHAR2(30) NOT NULL,
  LANGUAGE_NAME CHAR(2) NOT NULL,
  TRANSLATED_NAME NVARCHAR2(61),
  TRANSLATED_DESC NVARCHAR2(256),
  TRANSLATED_COMMENT NVARCHAR2(2000),
  CONSTRAINT PK_OBJECT_TRANSLATION
    PRIMARY KEY (ID)
);

CREATE SEQUENCE SAVETODB_DEV.SQ_OBJECT_TRANSLATION_ID
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER SAVETODB_DEV.TBIUR_OBJECT_TRANSLATION_ID
 BEFORE INSERT OR UPDATE
 ON SAVETODB_DEV.OBJECT_TRANSLATION
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT sq_OBJECT_TRANSLATION_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

CREATE UNIQUE INDEX SAVETODB_DEV.IX_OBJECT_TRANSLATION_S_N_L
    ON SAVETODB_DEV.OBJECT_TRANSLATION (
    TABLE_SCHEMA,
    TABLE_NAME,
    LANGUAGE_NAME
);

CREATE TABLE SAVETODB_DEV.COLUMN_TRANSLATION
(
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30),
  TABLE_NAME VARCHAR2(30),
  COLUMN_NAME VARCHAR2(30) NOT NULL,
  LANGUAGE_NAME CHAR(2) NOT NULL,
  TRANSLATED_NAME NVARCHAR2(61),
  TRANSLATED_DESC NVARCHAR2(1024),
  CONSTRAINT PK_COLUMN_TRANSLATION
    PRIMARY KEY (ID)
);

CREATE SEQUENCE SAVETODB_DEV.SQ_COLUMN_TRANSLATION_ID
  INCREMENT BY 1
  START WITH 1
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER SAVETODB_DEV.TBIUR_COLUMN_TRANSLATION_ID
 BEFORE INSERT OR UPDATE
 ON SAVETODB_DEV.COLUMN_TRANSLATION
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT sq_COLUMN_TRANSLATION_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

GRANT SELECT ON SAVETODB_DEV.COLUMN_TRANSLATION TO SAVETODB_XLS WITH GRANT OPTION;
GRANT SELECT ON SAVETODB_DEV.OBJECT_TRANSLATION TO SAVETODB_XLS WITH GRANT OPTION;

CREATE UNIQUE INDEX SAVETODB_DEV.IX_COLUMN_TRANSLATION_S_N_C_L
    ON SAVETODB_DEV.COLUMN_TRANSLATION (
    TABLE_SCHEMA,
    TABLE_NAME,
    COLUMN_NAME,
    LANGUAGE_NAME
);

CREATE OR REPLACE VIEW SAVETODB_XLS.VIEW_OBJECT_TRANSLATION
(
  ID,
  TABLE_SCHEMA,
  TABLE_NAME,
  LANGUAGE_NAME,
  TRANSLATED_NAME,
  TRANSLATED_DESC,
  TRANSLATED_COMMENT
)
AS
  SELECT
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.LANGUAGE_NAME,
    t.TRANSLATED_NAME,
    t.TRANSLATED_DESC,
    t.TRANSLATED_COMMENT
  FROM
    SAVETODB_DEV.OBJECT_TRANSLATION t
  ORDER BY
    t.LANGUAGE_NAME,
    t.TABLE_SCHEMA,
    t.TABLE_NAME;

CREATE OR REPLACE VIEW SAVETODB_XLS.VIEW_COLUMN_TRANSLATION
(
  ID,
  TABLE_SCHEMA,
  TABLE_NAME,
  COLUMN_NAME,
  LANGUAGE_NAME,
  TRANSLATED_NAME,
  TRANSLATED_DESC
)
AS
  SELECT
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.COLUMN_NAME,
    t.LANGUAGE_NAME,
    t.TRANSLATED_NAME,
    t.TRANSLATED_DESC
  FROM
    SAVETODB_DEV.COLUMN_TRANSLATION t
  ORDER BY
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.COLUMN_NAME;

CREATE OR REPLACE VIEW SAVETODB_XLS.VIEW_OBJECT_DESCRIPTION
(
    ID
    , LANGUAGE_NAME
    , TABLE_SCHEMA
    , TABLE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_COMMENT
)
AS
    SELECT
        t.ID
        , t.LANGUAGE_NAME
        , t.TABLE_SCHEMA
        , t.TABLE_NAME
        , t.TRANSLATED_NAME
        , t.TRANSLATED_COMMENT
    FROM
        SAVETODB_DEV.OBJECT_TRANSLATION t
    WHERE
        t.TRANSLATED_NAME IS NOT NULL           -- This name is used in QueryList
        AND t.TRANSLATED_COMMENT IS NOT NULL    -- This comment for users
        AND NOT TABLE_NAME IN (                 -- SDK objects are not showed
              'VIEW_QUERY_LIST'
            , 'EVENT_HANDLERS'                  -- SaveToDB Framework 3.0
            , 'PARAMETER_VALUES'
            , 'OBJECT_TRANSLATION'
            , 'COLUMN_TRANSLATION'
            , 'TABLE_FORMATS'
            , 'VIEW_EVENT_HANDLERS'
            , 'VIEW_PARAMETER_VALUES'
            , 'VIEW_OBJECT_TRANSLATION'
            , 'VIEW_COLUMN_TRANSLATION'
            , 'VIEW_TABLE_FORMATS'
            , 'TABLE_FORMAT_SAVE'
            , 'EXCEL_EVENT_HANDLERS'            -- SaveToDB Framework 2.0
            , 'TRANSLATION_OBJECTS'
            , 'TRANSLATION_COLUMNS'
            , 'EXCEL_TABLE_FORMATS'
            , 'VIEW_EXCEL_EVENT_HANDLERS'
            , 'VIEW_PARAMETER_VALUES_QUERIES'
            , 'VIEW_TRANSLATION_OBJECTS'
            , 'VIEW_TRANSLATION_COLUMNS'
            , 'VIEW_EXCEL_TABLE_FORMATS'
            , 'EXCEL_TABLE_FORMAT_UPDATE'
            )
        AND NOT t.TABLE_NAME LIKE '%_INSERT'    -- Edit procedures
        AND NOT t.TABLE_NAME LIKE '%_UPDATE'
        AND NOT t.TABLE_NAME LIKE '%_DELETE'
        AND NOT t.TABLE_NAME LIKE '%_MERGE'
        AND NOT t.TABLE_NAME LIKE 'XL_%'        -- Event handlers and parameter values
    ORDER BY
        t.LANGUAGE_NAME,
        t.TABLE_SCHEMA,
        t.TABLE_NAME;

prompt Translation objects have been created

CREATE TABLE SAVETODB_DEV.EVENT_HANDLERS
(
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30) NOT NULL,
  TABLE_NAME VARCHAR2(30) NOT NULL,
  COLUMN_NAME VARCHAR2(30),
  EVENT_NAME VARCHAR2(11) NOT NULL,
  HANDLER_SCHEMA VARCHAR2(30),
  HANDLER_NAME VARCHAR2(256) NOT NULL,
  HANDLER_TYPE VARCHAR2(30),
  HANDLER_CODE NCLOB,
  TARGET_WORKSHEET VARCHAR2(256),
  MENU_ORDER NUMBER(3,0),
  EDIT_PARAMETERS NUMBER(1,0),
  CONSTRAINT PK_EVENT_HANDLERS
    PRIMARY KEY (ID)
);

CREATE SEQUENCE SAVETODB_DEV.SQ_EVENT_HANDLERS_ID
  INCREMENT BY 1
  START WITH 41
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER SAVETODB_DEV.TBIUR_EVENT_HANDLERS_ID
 BEFORE INSERT OR UPDATE
 ON SAVETODB_DEV.EVENT_HANDLERS
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT sq_EVENT_HANDLERS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

GRANT SELECT ON SAVETODB_DEV.EVENT_HANDLERS TO SAVETODB_XLS WITH GRANT OPTION;

CREATE OR REPLACE VIEW SAVETODB_XLS.VIEW_EVENT_HANDLERS
(
    ID,
    TABLE_SCHEMA,
    TABLE_NAME,
    COLUMN_NAME,
    EVENT_NAME,
    HANDLER_SCHEMA,
    HANDLER_NAME,
    HANDLER_TYPE,
    HANDLER_CODE,
    TARGET_WORKSHEET,
    MENU_ORDER,
    EDIT_PARAMETERS
)
AS
SELECT
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.COLUMN_NAME,
    t.EVENT_NAME,
    t.HANDLER_SCHEMA,
    t.HANDLER_NAME,
    t.HANDLER_TYPE,
    t.HANDLER_CODE,
    t.TARGET_WORKSHEET,
    t.MENU_ORDER,
    t.EDIT_PARAMETERS
FROM
    SAVETODB_DEV.EVENT_HANDLERS t;

prompt EventHandlers objects have been created

CREATE TABLE SAVETODB_DEV.PARAMETER_VALUES
(
  ID NUMBER NOT NULL,
  TABLE_SCHEMA VARCHAR2(30) NOT NULL,
  TABLE_NAME VARCHAR2(30) NOT NULL,
  PARAMETER_NAME VARCHAR2(30) NOT NULL,
  SELECT_SCHEMA VARCHAR2(30),
  SELECT_NAME VARCHAR2(30) NOT NULL,
  SELECT_TYPE VARCHAR2(10),
  SELECT_CODE NCLOB,
  CONSTRAINT PK_PARAMETER_VALUES
    PRIMARY KEY (ID)
);

CREATE SEQUENCE SAVETODB_DEV.SQ_PARAMETER_VALUES_ID
  INCREMENT BY 1
  START WITH 41
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER SAVETODB_DEV.TBIUR_PARAMETER_VALUES_ID
 BEFORE INSERT OR UPDATE
 ON SAVETODB_DEV.PARAMETER_VALUES
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT sq_PARAMETER_VALUES_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

GRANT SELECT ON SAVETODB_DEV.PARAMETER_VALUES TO SAVETODB_XLS WITH GRANT OPTION;

CREATE UNIQUE INDEX SAVETODB_DEV.IX_PARAMETER_VALUES_S_N_P
    ON SAVETODB_DEV.PARAMETER_VALUES (
    TABLE_SCHEMA,
    TABLE_NAME,
    PARAMETER_NAME
);

CREATE OR REPLACE VIEW SAVETODB_XLS.VIEW_PARAMETER_VALUES
(
    ID,
    TABLE_SCHEMA,
    TABLE_NAME,
    PARAMETER_NAME,
    SELECT_SCHEMA,
    SELECT_NAME,
    SELECT_TYPE,
    SELECT_CODE
)
AS
SELECT 
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.PARAMETER_NAME,
    t.SELECT_SCHEMA,
    t.SELECT_NAME,
    t.SELECT_TYPE,
    t.SELECT_CODE
FROM 
    SAVETODB_DEV.PARAMETER_VALUES t;

prompt ParameterValues  objects have been created

CREATE TABLE SAVETODB_DEV.TABLE_FORMATS
(
  ID NUMBER,
  TABLE_SCHEMA VARCHAR2(30) NOT NULL,
  TABLE_NAME VARCHAR2(30) NOT NULL,
  TABLE_EXCEL_FORMAT_XML NCLOB,
  CONSTRAINT PK_TABLE_FORMATS
    PRIMARY KEY (ID)
);

CREATE SEQUENCE SAVETODB_DEV.SQ_TABLE_FORMATS_ID
  INCREMENT BY 1
  START WITH 21
  MAXVALUE 1E28
  MINVALUE 1
  NOCYCLE
  CACHE 20
  NOORDER;

CREATE TRIGGER SAVETODB_DEV.TBIUR_TABLE_FORMATS_ID
 BEFORE INSERT OR UPDATE
 ON SAVETODB_DEV.TABLE_FORMATS
REFERENCING NEW AS NEW OLD AS OLD FOR EACH ROW
BEGIN
  IF :new.ID IS NULL THEN
    SELECT sq_TABLE_FORMATS_ID.NEXTVAL INTO :new.ID FROM dual;
  END IF;
END;
/

GRANT SELECT ON SAVETODB_DEV.TABLE_FORMATS TO SAVETODB_XLS WITH GRANT OPTION;

CREATE UNIQUE INDEX SAVETODB_DEV.IX_TABLE_FORMATS_S_N
    ON SAVETODB_DEV.TABLE_FORMATS (
    TABLE_SCHEMA,
    TABLE_NAME
);

CREATE OR REPLACE VIEW SAVETODB_XLS.VIEW_TABLE_FORMATS
(
  ID,
  TABLE_SCHEMA,
  TABLE_NAME,
  TABLE_EXCEL_FORMAT_XML
)
AS
  SELECT
    t.ID,
    t.TABLE_SCHEMA,
    t.TABLE_NAME,
    t.TABLE_EXCEL_FORMAT_XML
  FROM
    SAVETODB_DEV.TABLE_FORMATS t;


CREATE PROCEDURE SAVETODB_DEV.TABLE_FORMAT_SAVE (
    Schema IN NVARCHAR2,
    Name IN NVARCHAR2,
    ExcelFormatXML NCLOB
    )
IS
    RowCount NUMBER;
BEGIN
    IF NOT (Schema IS NULL AND Name IS NULL) THEN
        IF (ExcelFormatXML IS NULL) THEN
            DELETE SAVETODB_DEV.TABLE_FORMATS
            WHERE
                TABLE_SCHEMA = Schema AND TABLE_NAME = Name;
        ELSE
            SELECT COUNT(*) INTO RowCount
            FROM SAVETODB_DEV.TABLE_FORMATS
            WHERE
                TABLE_SCHEMA = Schema AND TABLE_NAME = Name;

            IF (RowCount = 0) THEN
                INSERT INTO SAVETODB_DEV.TABLE_FORMATS
                    (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML)
                VALUES
                    (Schema, Name, ExcelFormatXML);
            ELSE
                UPDATE SAVETODB_DEV.TABLE_FORMATS
                SET
                    TABLE_SCHEMA = Schema,
                    TABLE_NAME = Name,
                    TABLE_EXCEL_FORMAT_XML = ExcelFormatXML
                WHERE
                    TABLE_SCHEMA = Schema AND TABLE_NAME = Name;
            END IF;
        END IF;
    END IF;
END;
/

prompt TableFormats objects have been created

CREATE ROLE SAVETODB_XLS_ROLE   NOT IDENTIFIED;
CREATE ROLE SAVETODB_DEV_ROLE   NOT IDENTIFIED;

prompt Roles have been created

GRANT CREATE SESSION    TO SAVETODB_XLS;
GRANT CREATE SESSION    TO SAVETODB_DEV;

GRANT CREATE VIEW       TO SAVETODB_XLS;

GRANT CREATE TABLE      TO SAVETODB_DEV;
GRANT CREATE VIEW       TO SAVETODB_DEV;
GRANT CREATE TRIGGER    TO SAVETODB_DEV;
GRANT CREATE PROCEDURE  TO SAVETODB_DEV;
GRANT CREATE SEQUENCE   TO SAVETODB_DEV;


GRANT SAVETODB_XLS_ROLE TO SAVETODB_DEV_ROLE;


GRANT SELECT    ON SAVETODB_XLS.VIEW_QUERY_LIST                 TO SAVETODB_XLS_ROLE;
GRANT SELECT    ON SAVETODB_XLS.VIEW_EVENT_HANDLERS             TO SAVETODB_XLS_ROLE;
GRANT SELECT    ON SAVETODB_XLS.VIEW_PARAMETER_VALUES           TO SAVETODB_XLS_ROLE;
GRANT SELECT    ON SAVETODB_XLS.VIEW_OBJECT_TRANSLATION         TO SAVETODB_XLS_ROLE;
GRANT SELECT    ON SAVETODB_XLS.VIEW_COLUMN_TRANSLATION         TO SAVETODB_XLS_ROLE;
GRANT SELECT    ON SAVETODB_XLS.VIEW_TABLE_FORMATS              TO SAVETODB_XLS_ROLE;
GRANT SELECT    ON SAVETODB_XLS.VIEW_OBJECT_DESCRIPTION         TO SAVETODB_XLS_ROLE;

GRANT SELECT    ON SAVETODB_DEV.QUERY_LIST                      TO SAVETODB_XLS WITH GRANT OPTION;
GRANT SELECT    ON SAVETODB_DEV.EVENT_HANDLERS                  TO SAVETODB_XLS WITH GRANT OPTION;
GRANT SELECT    ON SAVETODB_DEV.PARAMETER_VALUES                TO SAVETODB_XLS WITH GRANT OPTION;
GRANT SELECT    ON SAVETODB_DEV.OBJECT_TRANSLATION              TO SAVETODB_XLS WITH GRANT OPTION;
GRANT SELECT    ON SAVETODB_DEV.COLUMN_TRANSLATION              TO SAVETODB_XLS WITH GRANT OPTION;
GRANT SELECT    ON SAVETODB_DEV.TABLE_FORMATS                   TO SAVETODB_XLS WITH GRANT OPTION;

GRANT SELECT    ON SAVETODB_DEV.VIEW_QUERY_LIST                 TO SAVETODB_XLS WITH GRANT OPTION;
GRANT SELECT    ON SAVETODB_DEV.VIEW_QUERY_LIST                 TO SAVETODB_DEV_ROLE;

GRANT DELETE, INSERT, SELECT, UPDATE ON SAVETODB_DEV.QUERY_LIST             TO SAVETODB_DEV_ROLE;
GRANT DELETE, INSERT, SELECT, UPDATE ON SAVETODB_DEV.EVENT_HANDLERS         TO SAVETODB_DEV_ROLE;
GRANT DELETE, INSERT, SELECT, UPDATE ON SAVETODB_DEV.PARAMETER_VALUES       TO SAVETODB_DEV_ROLE;
GRANT DELETE, INSERT, SELECT, UPDATE ON SAVETODB_DEV.OBJECT_TRANSLATION     TO SAVETODB_DEV_ROLE;
GRANT DELETE, INSERT, SELECT, UPDATE ON SAVETODB_DEV.COLUMN_TRANSLATION     TO SAVETODB_DEV_ROLE;
GRANT DELETE, INSERT, SELECT, UPDATE ON SAVETODB_DEV.TABLE_FORMATS          TO SAVETODB_DEV_ROLE;

GRANT SELECT    ON SAVETODB_DEV.SQ_QUERY_LIST_ID                TO SAVETODB_DEV_ROLE;
GRANT SELECT    ON SAVETODB_DEV.SQ_EVENT_HANDLERS_ID            TO SAVETODB_DEV_ROLE;
GRANT SELECT    ON SAVETODB_DEV.SQ_PARAMETER_VALUES_ID          TO SAVETODB_DEV_ROLE;
GRANT SELECT    ON SAVETODB_DEV.SQ_OBJECT_TRANSLATION_ID        TO SAVETODB_DEV_ROLE;
GRANT SELECT    ON SAVETODB_DEV.SQ_COLUMN_TRANSLATION_ID        TO SAVETODB_DEV_ROLE;
GRANT SELECT    ON SAVETODB_DEV.SQ_TABLE_FORMATS_ID             TO SAVETODB_DEV_ROLE;

GRANT EXECUTE   ON SAVETODB_DEV.TABLE_FORMAT_SAVE               TO SAVETODB_DEV_ROLE;

prompt Grants have been added

ALTER SESSION SET NLS_DATE_FORMAT='YYYY-MM-DD HH24:MI:SS';
ALTER SESSION SET NLS_TIMESTAMP_FORMAT='YYYY-MM-DD HH24:MI:SSXFF';
ALTER SESSION SET NLS_TIMESTAMP_TZ_FORMAT='YYYY-MM-DD HH24:MI:SSXFF TZH:TZM';

INSERT INTO "SAVETODB_DEV"."QUERY_LIST" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_TYPE", "TABLE_CODE", "INSERT_PROCEDURE", "UPDATE_PROCEDURE", "DELETE_PROCEDURE", "PROCEDURE_TYPE") VALUES ('SAVETODB_XLS', 'VIEW_TABLE_FORMATS',      'VIEW', NULL, 'SAVETODB_DEV.TABLE_FORMATS', 'SAVETODB_DEV.TABLE_FORMATS', 'SAVETODB_DEV.TABLE_FORMATS', 'TABLE');
INSERT INTO "SAVETODB_DEV"."QUERY_LIST" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_TYPE", "TABLE_CODE", "INSERT_PROCEDURE", "UPDATE_PROCEDURE", "DELETE_PROCEDURE", "PROCEDURE_TYPE") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES',   'VIEW', NULL, 'SAVETODB_DEV.PARAMETER_VALUES', 'SAVETODB_DEV.PARAMETER_VALUES', 'SAVETODB_DEV.PARAMETER_VALUES', 'TABLE');
INSERT INTO "SAVETODB_DEV"."QUERY_LIST" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_TYPE", "TABLE_CODE", "INSERT_PROCEDURE", "UPDATE_PROCEDURE", "DELETE_PROCEDURE", "PROCEDURE_TYPE") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS',     'VIEW', NULL, 'SAVETODB_DEV.EVENT_HANDLERS', 'SAVETODB_DEV.EVENT_HANDLERS', 'SAVETODB_DEV.EVENT_HANDLERS', 'TABLE');
INSERT INTO "SAVETODB_DEV"."QUERY_LIST" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_TYPE", "TABLE_CODE", "INSERT_PROCEDURE", "UPDATE_PROCEDURE", "DELETE_PROCEDURE", "PROCEDURE_TYPE") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_DESCRIPTION', 'VIEW', NULL, 'SAVETODB_DEV.OBJECT_TRANSLATION', 'SAVETODB_DEV.OBJECT_TRANSLATION', 'SAVETODB_DEV.OBJECT_TRANSLATION', 'TABLE');
INSERT INTO "SAVETODB_DEV"."QUERY_LIST" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_TYPE", "TABLE_CODE", "INSERT_PROCEDURE", "UPDATE_PROCEDURE", "DELETE_PROCEDURE", "PROCEDURE_TYPE") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'VIEW', NULL, 'SAVETODB_DEV.OBJECT_TRANSLATION', 'SAVETODB_DEV.OBJECT_TRANSLATION', 'SAVETODB_DEV.OBJECT_TRANSLATION', 'TABLE');
INSERT INTO "SAVETODB_DEV"."QUERY_LIST" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_TYPE", "TABLE_CODE", "INSERT_PROCEDURE", "UPDATE_PROCEDURE", "DELETE_PROCEDURE", "PROCEDURE_TYPE") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'VIEW', NULL, 'SAVETODB_DEV.COLUMN_TRANSLATION', 'SAVETODB_DEV.COLUMN_TRANSLATION', 'SAVETODB_DEV.COLUMN_TRANSLATION', 'TABLE');

INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_DEV',N'COLUMN_TRANSLATION',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-translation.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_DEV',N'OBJECT_TRANSLATION',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-translation.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_DEV',N'EVENT_HANDLERS',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-event-handlers.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_DEV',N'PARAMETER_VALUES',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-parameter-values.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_DEV',N'QUERY_LIST',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-query-list.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_DEV',N'TABLE_FORMATS',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-table-formats.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_XLS',N'VIEW_COLUMN_TRANSLATION',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-translation.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_XLS',N'VIEW_OBJECT_TRANSLATION',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-translation.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_XLS',N'VIEW_EVENT_HANDLERS',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-event-handlers.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_XLS',N'VIEW_PARAMETER_VALUES',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-parameter-values.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_DEV',N'VIEW_QUERY_LIST',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-query-list.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_XLS',N'VIEW_QUERY_LIST',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-query-list.htm',NULL,11,NULL);
INSERT INTO "SAVETODB_DEV"."EVENT_HANDLERS" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "EVENT_NAME", "HANDLER_SCHEMA", "HANDLER_NAME", "HANDLER_TYPE", "HANDLER_CODE", "TARGET_WORKSHEET", "MENU_ORDER", "EDIT_PARAMETERS") VALUES (N'SAVETODB_XLS',N'VIEW_TABLE_FORMATS',NULL,N'Actions',N'HTTP',N'Online Help',N'HTTP',N'http://www.savetodb.com/help4/configuring-table-formats.htm',NULL,11,NULL);

INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', 'en', NULL, 'Configuration Table of Column Translation', 'The table defines translation for Excel table headers and ribbon fields');
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'en', NULL, 'Configuration Table of Excel Event Handlers', 'The table defines Excel event handlers and Actions and Context Menu items');
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', 'en', NULL, 'Configuration Table of Object Translation', 'The table defines translation for Query List, Actions and Context Menu items');
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'en', NULL, 'Configuration Table of Parameter Value Queries', 'The table defines objects to select ribbon parameter values');
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'en', NULL, 'Configuration Table of Query List', 'The table defines configuration of Query List objects');
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_DEV', 'TABLE_FORMAT_SAVE', 'en', NULL, 'Configuration Procedure to Save Table Formats', 'The procedure is used to save Excel formats of database objects');
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_DEV', 'TABLE_FORMATS', 'en', NULL, 'Configuration Table of Excel Table Formats', 'The table contains Excel formats of database objects');
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'en', NULL, 'Configuration View of Column Translation', NULL);
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'en', NULL, 'Configuration View of Excel Event Handlers', NULL);
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_DESCRIPTION', 'en', 'Object Descriptions', 'Database Object Descriptions', 'You may use Query List to connect to these objects');
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'en', NULL, 'Configuration View of Object Translation', NULL);
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'en', NULL, 'Configuration View of Parameter Value Queries', NULL);
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'en', 'Framework Query List', 'Configuration View of Query List', NULL);
INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES ('SAVETODB_XLS', 'VIEW_TABLE_FORMATS', 'en', NULL, 'Configuration View of Excel Table Formats', NULL);

INSERT INTO "SAVETODB_DEV"."OBJECT_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC", "TRANSLATED_COMMENT") VALUES (N'HTTP', N'Online Help', N'en', N'Online Help', NULL, NULL);

INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'TABLE_NAME', 'en', NULL, 'Database object name or unique name for SQL-code and http-query');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'TABLE_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'INSERT_PROCEDURE', 'en', NULL, 'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'UPDATE_PROCEDURE', 'en', NULL, 'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'QUERY_LIST', 'DELETE_PROCEDURE', 'en', NULL, 'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'TABLE_NAME', 'en', NULL, 'Database object name, SQL-code name, or http-query name');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'COLUMN_NAME', 'en', NULL, 'Column name or NULL to use the handler for entire table');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'EVENT_NAME', 'en', NULL, 'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'HANDLER_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'HANDLER_NAME', 'en', NULL, 'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'HANDLER_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'TARGET_WORKSHEET', 'en', NULL, 'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'MENU_ORDER', 'en', NULL, 'Sort order of Actions and Context Menu items');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', 'EDIT_PARAMETERS', 'en', NULL, 'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'TABLE_NAME', 'en', NULL, 'Database object name');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'PARAMETER_NAME', 'en', NULL, 'Column or parameter name');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'SELECT_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'SELECT_NAME', 'en', NULL, 'Database object name or name for SQL-code');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', 'SELECT_TYPE', 'en', NULL, 'Database object type or CODE for SQL-code');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', 'TABLE_NAME', 'en', NULL, 'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Query List, Actions and Context Menus');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', 'TRANSLATED_DESC', 'en', NULL, 'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', 'TRANSLATED_COMMENT', 'en', NULL, 'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema or NULL for entire database scope');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', 'TABLE_NAME', 'en', NULL, 'Database object name or NULL for entire schema scope');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', 'COLUMN_NAME', 'en', NULL, 'Column or parameter name');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Excel table headers and ribbon parameters');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', 'TRANSLATED_DESC', 'en', NULL, 'Text for Excel table header comments and ribbon parameter SuperTips');

INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'TABLE_NAME', 'en', NULL, 'Database object name or unique name for SQL-code and http-query');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'TABLE_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, or HTTP for http-query');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'INSERT_PROCEDURE', 'en', NULL, 'Insert procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'UPDATE_PROCEDURE', 'en', NULL, 'Update procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_QUERY_LIST', 'DELETE_PROCEDURE', 'en', NULL, 'Delete procedure or destination table to save changes of views, procedures, or SQL-codes');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'TABLE_NAME', 'en', NULL, 'Database object name, SQL-code name, or http-query name');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'COLUMN_NAME', 'en', NULL, 'Column name or NULL to use the handler for entire table');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'EVENT_NAME', 'en', NULL, 'Actions, Change, ContextMenu, DoubleClick, or SelectionChange');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'HANDLER_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'HANDLER_NAME', 'en', NULL, 'Database object name, unique name for SQL-code and http-query, or MenuSeparator');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'HANDLER_TYPE', 'en', NULL, 'Database object type, CODE for SQL-code, HTTP for http-query, or NULL for MenuSeparator');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'TARGET_WORKSHEET', 'en', NULL, 'NULL, sheet name, _new, _self, _reload. Additions: _RightWindow, _LeftWindow, _TopWindow, _BottomWindow');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'MENU_ORDER', 'en', NULL, 'Sort order of Actions and Context Menu items');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_EVENT_HANDLERS', 'EDIT_PARAMETERS', 'en', NULL, 'Show the Edit Parameters dialog box for Actions and Context Menu items: True/False/NULL (default behavior)');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'TABLE_NAME', 'en', NULL, 'Database object name');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'PARAMETER_NAME', 'en', NULL, 'Column or parameter name');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'SELECT_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'SELECT_NAME', 'en', NULL, 'Database object name or name for SQL-code');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_PARAMETER_VALUES', 'SELECT_TYPE', 'en', NULL, 'Database object type or CODE for SQL-code');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'TABLE_NAME', 'en', NULL, 'Database object name or a name of SQL-code or http-query specified in Query List and Event Handlers');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Query List, Actions and Context Menus');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'TRANSLATED_DESC', 'en', NULL, 'Text for ScreenTips and SaveToDB_Desc named cells');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_TRANSLATION', 'TRANSLATED_COMMENT', 'en', NULL, 'Text for SuperTips and SaveToDB_Comment named cells');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'ID', 'en', NULL, NULL);
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'TABLE_SCHEMA', 'en', NULL, 'Database object schema or NULL for entire database scope');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'TABLE_NAME', 'en', NULL, 'Database object name or NULL for entire schema scope');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'COLUMN_NAME', 'en', NULL, 'Column or parameter name');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'LANGUAGE_NAME', 'en', NULL, 'Two-char language code');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'TRANSLATED_NAME', 'en', NULL, 'Translated name for Excel table headers and ribbon parameters');
INSERT INTO "SAVETODB_DEV"."COLUMN_TRANSLATION" ("TABLE_SCHEMA", "TABLE_NAME", "COLUMN_NAME", "LANGUAGE_NAME", "TRANSLATED_NAME", "TRANSLATED_DESC") VALUES ('SAVETODB_XLS', 'VIEW_COLUMN_TRANSLATION', 'TRANSLATED_DESC', 'en', NULL, 'Text for Excel table header comments and ribbon parameter SuperTips');

INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_XLS', 'VIEW_OBJECT_DESCRIPTION', TO_NCLOB('<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_XLS.VIEW_OBJECT_DESCRIPTION">
<columnFormats>
<column name="" property="ListObjectName" value="DevObjects_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$D$7" type="String" />
<column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$E$7" type="String" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$F$7" type="String" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="22.29" type="Double" />
<column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_COMMENT" property="ColumnWidth" value="95.71" type="Double" />
<column name="TRANSLATED_COMMENT" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_COMMENT" property="WrapText" value="True" type="Boolean" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
'));
INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_DEV', 'QUERY_LIST', TO_NCLOB('<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_DEV.QUERY_LIST">
<columnFormats>
<column name="" property="ListObjectName" value="QueryList_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="2" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="4" type="Double" />
<column name="ID" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="2000" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="27.86" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean" />') || TO_NCLOB('
<column name="TABLE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_TYPE" property="Address" value="$F$7" type="String" />
<column name="TABLE_TYPE" property="ColumnWidth" value="13.14" type="Double" />
<column name="TABLE_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="TABLE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;CODE;HTTP;TEXT" type="String" />
<column name="TABLE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_CODE" property="Address" value="$G$7" type="String" />
<column name="TABLE_CODE" property="ColumnWidth" value="13.57" type="Double" />
<column name="INSERT_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Address" value="$H$7" type="String" />
<column name="INSERT_PROCEDURE" property="ColumnWidth" value="37" type="Double" />
<column name="INSERT_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="INSERT_PROCEDURE" property="Validation.Type" value="6" type="Double" />
<column name="INSERT_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="INSERT_PROCEDURE" property="Validation.Operator" value="8" type="Double" />
<column name="INSERT_PROCEDURE" property="Validation.Formula1" value="61" type="String" />
<column name="INSERT_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="INSERT_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Address" value="$I$7" type="String" />
<column name="UPDATE_PROCEDURE" property="ColumnWidth" value="37" type="Double" />
<column name="UPDATE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="UPDATE_PROCEDURE" property="Validation.Type" value="6" type="Double" />
<column name="UPDATE_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="UPDATE_PROCEDURE" property="Validation.Operator" value="8" type="Double" />
<column name="UPDATE_PROCEDURE" property="Validation.Formula1" value="61" type="String" />
<column name="UPDATE_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="UPDATE_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="DELETE_PROCEDURE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Address" value="$J$7" type="String" />
<column name="DELETE_PROCEDURE" property="ColumnWidth" value="37" type="Double" />
<column name="DELETE_PROCEDURE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="DELETE_PROCEDURE" property="Validation.Type" value="6" type="Double" />
<column name="DELE') || TO_NCLOB('TE_PROCEDURE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="DELETE_PROCEDURE" property="Validation.Operator" value="8" type="Double" />
<column name="DELETE_PROCEDURE" property="Validation.Formula1" value="61" type="String" />
<column name="DELETE_PROCEDURE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="DELETE_PROCEDURE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Address" value="$K$7" type="String" />
<column name="PROCEDURE_TYPE" property="ColumnWidth" value="18.43" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Operator" value="1" type="Double" />
<column name="PROCEDURE_TYPE" property="Validation.Formula1" value="TABLE;PROCEDURE;CODE;MERGE" type="String" />
<column name="PROCEDURE_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PROCEDURE_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="ID" property="FormatConditions(1).AppliesTo.Address" value="$C$7:$C$12" type="String" />
<column name="ID" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="ID" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="ID" property="FormatConditions(1).Formula1" value="=ISBLANK(C7)" type="String" />
<column name="ID" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="ID" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="ID" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$12" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$12" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="Active') || TO_NCLOB('Window.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
'));
INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_DEV', 'EVENT_HANDLERS', TO_NCLOB('<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_DEV.EVENT_HANDLERS">
<columnFormats>
<column name="" property="ListObjectName" value="EventHandlers_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="2" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="4" type="Double" />
<column name="ID" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="27.86" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boole') || TO_NCLOB('an" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="19" type="Double" />
<column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EVENT_NAME" property="Address" value="$G$7" type="String" />
<column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double" />
<column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="EVENT_NAME" property="Validation.Type" value="3" type="Double" />
<column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange" type="String" />
<column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String" />
<column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double" />
<column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_SCHEMA" property="Validation.Formula1" value="2000" type="String" />
<column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_NAME" property="Address" value="$I$7" type="String" />
<column name="HANDLER_NAME" property="ColumnWidth" value="26.14" type="Double" />
<column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_NAME" property="Validation.Formula1" value="256" type="String" />
<column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True"') || TO_NCLOB(' type="Boolean" />
<column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_TYPE" property="Address" value="$J$7" type="String" />
<column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double" />
<column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;REFRESH;MENUSEPARATOR" type="String" />
<column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="HANDLER_CODE" property="Address" value="$K$7" type="String" />
<column name="HANDLER_CODE" property="ColumnWidth" value="16.57" type="Double" />
<column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String" />
<column name="TARGET_WORKSHEET" property="ColumnWidth" value="44.86" type="Double" />
<column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double" />
<column name="TARGET_WORKSHEET" property="Validation.Formula1" value="30" type="String" />
<column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean" />
<column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="MENU_ORDER" property="Address" value="$M$7" type="String" />
<column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double" />
<column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double" />
<column name="MENU_ORDER" property="Validation.Type" value="2" type="Double" />
<column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double" />
<column name="MENU_ORDER" property="Validation.Operator" value="4" type="Double" />
<column name="MENU_ORDER" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="EDIT_PARAMETERS" property="A') || TO_NCLOB('ddress" value="$N$7" type="String" />
<column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double" />
<column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Type" value="2" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.AlertStyle" value="1" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Operator" value="4" type="Double" />
<column name="EDIT_PARAMETERS" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="EDIT_PARAMETERS" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="EDIT_PARAMETERS" property="Validation.ShowError" value="True" type="Boolean" />
<column name="ID" property="FormatConditions(1).AppliesTo.Address" value="$C$7:$C$25" type="String" />
<column name="ID" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="ID" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="ID" property="FormatConditions(1).Formula1" value="=ISBLANK(C7)" type="String" />
<column name="ID" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="ID" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="ID" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$25" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="EVENT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$25" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="HANDLER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
'));
INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_DEV', 'PARAMETER_VALUES', TO_NCLOB('<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_DEV.PARAMETER_VALUES">
<columnFormats>
<column name="" property="ListObjectName" value="ParameterValues_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="2" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="4" type="Double" />
<column name="ID" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" type="B') || TO_NCLOB('oolean" />
<column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="PARAMETER_NAME" property="Address" value="$F$7" type="String" />
<column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double" />
<column name="PARAMETER_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double" />
<column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="PARAMETER_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String" />
<column name="SELECT_SCHEMA" property="ColumnWidth" value="17.29" type="Double" />
<column name="SELECT_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_SCHEMA" property="Validation.Formula1" value="2000" type="String" />
<column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_NAME" property="Address" value="$H$7" type="String" />
<column name="SELECT_NAME" property="ColumnWidth" value="15.29" type="Double" />
<column name="SELECT_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_NAME" property="Validation.Type" value="6" type="Double" />
<column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_TYPE" property="Address" value="$I$7" type="String" />
<column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double" />
<column name="SELECT_TYPE" property="VerticalAlignment" value="-4160" type="Double" />
<column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double" />
<column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double" />
<column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double" />
<column name="SELECT_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP" type="String" />
<column name="SELECT_TYPE" property="Validation.Igno') || TO_NCLOB('reBlank" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean" />
<column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="SELECT_CODE" property="Address" value="$J$7" type="String" />
<column name="SELECT_CODE" property="ColumnWidth" value="54.29" type="Double" />
<column name="ID" property="FormatConditions(1).AppliesTo.Address" value="$C$7:$C$8" type="String" />
<column name="ID" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="ID" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="ID" property="FormatConditions(1).Formula1" value="=ISBLANK(C7)" type="String" />
<column name="ID" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="ID" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="ID" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$8" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="2" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$8" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).AppliesTo.Address" value="$F$7:$F$8" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Priority" value="4" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(F7)" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="PARAMETER_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$8" type="String" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Priority" value="5" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="SELECT_SCHEMA" property="For') || TO_NCLOB('matConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).AppliesTo.Address" value="$H$7:$H$8" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Priority" value="6" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(H7)" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).AppliesTo.Address" value="$I$7:$I$8" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Priority" value="7" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Formula1" value="=ISBLANK(I7)" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="SELECT_TYPE" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="False" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="False" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="-6" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
'));
INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_DEV', 'OBJECT_TRANSLATION', TO_NCLOB('<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_DEV.OBJECT_TRANSLATION">
<columnFormats>
<column name="" property="ListObjectName" value="ObjectTranslation_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="2" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="4" type="Double" />
<column name="ID" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="29.29" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" typ') || TO_NCLOB('e="Boolean" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$F$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="4.71" type="Double" />
<column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String" />
<column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$G$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double" />
<column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Formula1" value="61" type="String" />
<column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_DESC" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_DESC" property="ColumnWidth" value="43.86" type="Double" />
<column name="TRANSLATED_DESC" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Formula1" value="256" type="String" />
<column name="TRANSLATED_DESC" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Address" value="$I$7" type="String" />
<column name="TRANSLATED_COMMENT" property="ColumnWidth" value="70.71" type="Double" />
<column name="TRANSLATED_COMMENT" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_COMMENT" property="Validation.Formula1" v') || TO_NCLOB('alue="2000" type="String" />
<column name="TRANSLATED_COMMENT" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_COMMENT" property="Validation.ShowError" value="True" type="Boolean" />
<column name="ID" property="FormatConditions(1).ColumnsCount" value="4" type="Double" />
<column name="ID" property="FormatConditions(1).AppliesTo.Address" value="$C$7:$F$24" type="String" />
<column name="ID" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="ID" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="ID" property="FormatConditions(1).Formula1" value="=ISBLANK(C7)" type="String" />
<column name="ID" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="ID" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="ID" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="SortFields(1)" property="KeyfieldName" value="LANGUAGE_NAME" type="String" />
<column name="SortFields(1)" property="SortOn" value="0" type="Double" />
<column name="SortFields(1)" property="Order" value="1" type="Double" />
<column name="SortFields(1)" property="DataOption" value="0" type="Double" />
<column name="SortFields(2)" property="KeyfieldName" value="TABLE_SCHEMA" type="String" />
<column name="SortFields(2)" property="SortOn" value="0" type="Double" />
<column name="SortFields(2)" property="Order" value="1" type="Double" />
<column name="SortFields(2)" property="DataOption" value="0" type="Double" />
<column name="SortFields(3)" property="KeyfieldName" value="TABLE_NAME" type="String" />
<column name="SortFields(3)" property="SortOn" value="0" type="Double" />
<column name="SortFields(3)" property="Order" value="1" type="Double" />
<column name="SortFields(3)" property="DataOption" value="0" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
'));
INSERT INTO "SAVETODB_DEV"."TABLE_FORMATS" ("TABLE_SCHEMA", "TABLE_NAME", "TABLE_EXCEL_FORMAT_XML") VALUES ('SAVETODB_DEV', 'COLUMN_TRANSLATION', TO_NCLOB('<?xml version="1.0" encoding="Unicode"?>
<table name="SAVETODB_DEV.COLUMN_TRANSLATION">
<columnFormats>
<column name="" property="ListObjectName" value="ColumnTranslation_Table1" type="String" />
<column name="" property="ShowTotals" value="False" type="Boolean" />
<column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" />
<column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" />
<column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" />
<column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" />
<column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" />
<column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" />
<column name="_RowNum" property="Address" value="$B$7" type="String" />
<column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="ID" property="Address" value="$C$7" type="String" />
<column name="ID" property="ColumnWidth" value="4.43" type="Double" />
<column name="ID" property="VerticalAlignment" value="-4160" type="Double" />
<column name="ID" property="Validation.Type" value="2" type="Double" />
<column name="ID" property="Validation.AlertStyle" value="1" type="Double" />
<column name="ID" property="Validation.Operator" value="4" type="Double" />
<column name="ID" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" />
<column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="ID" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String" />
<column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double" />
<column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_SCHEMA" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TABLE_NAME" property="Address" value="$E$7" type="String" />
<column name="TABLE_NAME" property="ColumnWidth" value="27.86" type="Double" />
<column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TABLE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TABLE_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TABLE_NAME" property="Validation.ShowError" value="True" typ') || TO_NCLOB('e="Boolean" />
<column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="COLUMN_NAME" property="Address" value="$F$7" type="String" />
<column name="COLUMN_NAME" property="ColumnWidth" value="22.43" type="Double" />
<column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double" />
<column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="COLUMN_NAME" property="Validation.Formula1" value="30" type="String" />
<column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="LANGUAGE_NAME" property="Address" value="$G$7" type="String" />
<column name="LANGUAGE_NAME" property="ColumnWidth" value="3.57" type="Double" />
<column name="LANGUAGE_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Type" value="6" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="LANGUAGE_NAME" property="Validation.Formula1" value="2" type="String" />
<column name="LANGUAGE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="LANGUAGE_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_NAME" property="Address" value="$H$7" type="String" />
<column name="TRANSLATED_NAME" property="ColumnWidth" value="20.71" type="Double" />
<column name="TRANSLATED_NAME" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_NAME" property="Validation.Formula1" value="61" type="String" />
<column name="TRANSLATED_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_NAME" property="Validation.ShowError" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="EntireColumn.Hidden" value="False" type="Boolean" />
<column name="TRANSLATED_DESC" property="Address" value="$I$7" type="String" />
<column name="TRANSLATED_DESC" property="ColumnWidth" value="103.29" type="Double" />
<column name="TRANSLATED_DESC" property="VerticalAlignment" value="-4160" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Type" value="6" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.AlertStyle" value="1" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Operator" value="8" type="Double" />
<column name="TRANSLATED_DESC" property="Validation.Formula1" value="1024" type="String" />
<column name="TRANSLATED_DESC" property="V') || TO_NCLOB('alidation.IgnoreBlank" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.InCellDropdown" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowInput" value="True" type="Boolean" />
<column name="TRANSLATED_DESC" property="Validation.ShowError" value="True" type="Boolean" />
<column name="ID" property="FormatConditions(1).AppliesTo.Address" value="$C$7:$C$94" type="String" />
<column name="ID" property="FormatConditions(1).Type" value="2" type="Double" />
<column name="ID" property="FormatConditions(1).Priority" value="1" type="Double" />
<column name="ID" property="FormatConditions(1).Formula1" value="=ISBLANK(C7)" type="String" />
<column name="ID" property="FormatConditions(1).NumberFormat" value="General" type="String" />
<column name="ID" property="FormatConditions(1).Interior.Color" value="65535" type="Double" />
<column name="ID" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double" />
<column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" />
<column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" />
<column name="" property="ActiveWindow.Split" value="True" type="Boolean" />
<column name="" property="ActiveWindow.SplitRow" value="0" type="Double" />
<column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" />
<column name="" property="PageSetup.Orientation" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" />
<column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" />
</columnFormats>
</table>
'));

prompt SaveToDB Framework data have been added

prompt SaveToDB Framework has been installed
